@@ -24,8 +24,9 @@ has 'home' => (
     lazy_build => 1,
 );
 sub _build_home {
-    my $self = shift;
-    my $home =
+    my ($self, $home) = @_;
+
+    $home ||=
         Path::Class::Dir->new( File::HomeDir->my_home, '.TimeTracker' );
     unless (-d $home) {
         $home->mkpath;
@@ -76,6 +77,18 @@ sub run {
 
     my $config = $self->load_config;
 
+    my $class = $self->setup_class($config);
+
+    $class->name->new_with_options( {
+            home            => $self->home,
+            config          => $config,
+            ($self->has_project ? (_current_project=> $self->project) : ()),
+        } )->run;
+}
+
+sub setup_class {
+    my ($self, $config ) = @_;
+
     # unique plugins
     $config->{plugins} ||= [];
     my %plugins_unique = map {$_ =>  1} @{$config->{plugins}};
@@ -106,12 +119,7 @@ sub run {
         $class->name->$load_attribs_for_command($class);
     }
     $class->make_immutable();
-
-    $class->name->new_with_options( {
-            home            => $self->home,
-            config          => $config,
-            ($self->has_project ? (_current_project=> $self->project) : ()),
-        } )->run;
+    return $class;
 }
 
 sub load_config {
@@ -226,7 +234,7 @@ App::TimeTracker::Proto - App::TimeTracker Proto Class
 
 =head1 VERSION
 
-version 2.011
+version 2.012
 
 =head1 DESCRIPTION
 
